@@ -68,7 +68,7 @@ def get_person(html):
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     people = []
     html = f.get_html(URL)
     if html.status_code == 200:
