@@ -81,7 +81,7 @@ def get_link(str):
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     html = f.get_html(URL_JUDGE)
     if html.status_code == 200:
         people = get_people(html.text)
