@@ -16,7 +16,7 @@ URL = 'https://pravo.ru/arbitr_practice/courts/119/'
 
 
 def parser():
-    log.debug(f"The script {os.path.splitext('path_to_file')[0]} stops working")
+    log.debug(f"The script {__name__} starts working")
     people = []
     html = f.get_html(URL)
     if html.status_code == 200:
